Module: Grpc::Gateway::ProtocGenOpenapiv2::Options
- Defined in:
- lib/grpc/gateway/protoc_gen_openapiv2/options/openapiv2_pb.rb,
lib/grpc/gateway/protoc_gen_openapiv2/options/annotations_pb.rb
Defined Under Namespace
Classes: Contact, ExternalDocumentation, Header, HeaderParameter, Info, JSONSchema, License, Operation, Parameters, Response, Schema, Scheme, Scopes, SecurityDefinitions, SecurityRequirement, SecurityScheme, Swagger, Tag
Class Method Summary collapse
-
.register_annotations_protos(registry) ⇒ Object
ID assigned by protobuf-global-extension-registry@google.com for gRPC-Gateway project.
- .register_openapiv2_protos(registry) ⇒ Object
Class Method Details
.register_annotations_protos(registry) ⇒ Object
ID assigned by protobuf-global-extension-registry@google.com for gRPC-Gateway project.
All IDs are the same, as assigned. It is okay that they are the same, as they extend different descriptor messages. extension: google.protobuf.FieldOptions
openapiv2_field 1042
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/grpc/gateway/protoc_gen_openapiv2/options/annotations_pb.rb', line 56 def self.register_annotations_protos(registry) Google::Protobuf.register_descriptor_protos(registry) Grpc::Gateway::ProtocGenOpenapiv2::Options.register_openapiv2_protos( registry ) # extension: google.protobuf.FileOptions # TYPE_MESSAGE 1042 # extension: google.protobuf.MethodOptions # TYPE_MESSAGE 1042 # extension: google.protobuf.MessageOptions # TYPE_MESSAGE 1042 # extension: google.protobuf.ServiceOptions # TYPE_MESSAGE 1042 # extension: google.protobuf.FieldOptions # TYPE_MESSAGE 1042 end |