Class: Grpc::Gateway::ProtocGenOpenapiv2::Options::Parameters

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Message
Defined in:
lib/grpc/gateway/protoc_gen_openapiv2/options/openapiv2_pb.rb

Overview

‘Parameters` is a representation of OpenAPI v2 specification’s parameters object. Note: This technically breaks compatibility with the OpenAPI 2 definition structure as we only allow header parameters to be set here since we do not want users specifying custom non-header parameters beyond those inferred from the Protobuf schema. See: swagger.io/specification/v2/#parameter-object