Class: Grpc::Gateway::ProtocGenOpenapiv2::Options::SecurityRequirement

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Message
Defined in:
lib/grpc/gateway/protoc_gen_openapiv2/options/openapiv2_pb.rb

Overview

‘SecurityRequirement` is a representation of OpenAPI v2 specification’s Security Requirement object.

See: github.com/OAI/OpenAPI-Specification/blob/3.0.0/versions/2.0.md#securityRequirementObject

Lists the required security schemes to execute this operation. The object can have multiple security schemes declared in it which are all required (that is, there is a logical AND between the schemes).

The name used for each property MUST correspond to a security scheme declared in the Security Definitions.

Defined Under Namespace

Classes: SecurityRequirementValue