Class: Grpc::Gateway::ProtocGenOpenapiv2::Options::SecurityScheme
- Inherits:
-
Object
- Object
- Grpc::Gateway::ProtocGenOpenapiv2::Options::SecurityScheme
- Extended by:
- Protobug::Message
- Defined in:
- lib/grpc/gateway/protoc_gen_openapiv2/options/openapiv2_pb.rb
Overview
‘SecurityScheme` is a representation of OpenAPI v2 specification’s Security Scheme object.
See: github.com/OAI/OpenAPI-Specification/blob/3.0.0/versions/2.0.md#securitySchemeObject
Allows the definition of a security scheme that can be used by the operations. Supported schemes are basic authentication, an API key (either as a header or as a query parameter) and OAuth2’s common flows (implicit, password, application and access code).